@@ -73,6 +73,12 @@ class Command(BaseCommand):
 
         make_option('--xunit-file', action='store', dest='xunit_file', default=None,
             help='Write JUnit XML to this file. Defaults to lettucetests.xml'),
+
+        make_option("--failfast", dest="failfast", default=False,
+                    action="store_true", help='Stop running in the first failure'),
+
+        make_option("--pdb", dest="auto_pdb", default=False,
+                    action="store_true", help='Launches an interactive debugger upon error'),
     )
 
     def stopserver(self, failed=False):
@@ -101,6 +107,9 @@ class Command(BaseCommand):
         apps_to_avoid = tuple(options.get('avoid_apps', '').split(","))
         run_server = not options.get('no_server', False)
         tags = options.get('tags', None)
+        failfast = options.get('failfast', False)
+        auto_pdb = options.get('auto_pdb', False)
+
         server = Server(port=options['port'])
 
         paths = self.get_paths(args, apps_to_run, apps_to_avoid)
@@ -129,7 +138,7 @@ class Command(BaseCommand):
                 runner = Runner(path, options.get('scenarios'), verbosity,
                                 enable_xunit=options.get('enable_xunit'),
                                 xunit_filename=options.get('xunit_file'),
-                                tags=tags)
+                                tags=tags, failfast=failfast, auto_pdb=auto_pdb)
 
                 result = runner.run()
                 if app_module is not None:
@@ -138,8 +147,11 @@ class Command(BaseCommand):
                 results.append(result)
                 if not result or result.steps != result.steps_passed:
                     failed = True
+        except SystemExit, e:
+            failed = e.code
 
         except Exception, e:
+            failed = True
             import traceback
             traceback.print_exc(e)
 
